module derivs_param

  implicit none

  real eps_cp_m ! entrainment coefficient at the border of the cold pool
  !$omp THREADPRIVATE(eps_cp)

  real beta_m ! entrainment at the top of the mixed layer
  !$omp THREADPRIVATE(beta)

  logical av_thvu_constant_m
  !$omp THREADPRIVATE(av_thvu_constant)

  real k_star_m
  !$omp THREADPRIVATE(k_star)

  real theta_vs_m ! surface virtual potential temperature, in K
  !$omp THREADPRIVATE(theta_vs_m)

  real rate_uns_m ! mass rate in one unsaturated downdraft, in kg s-1
  !$omp THREADPRIVATE(rate_uns)

  real av_rho_m ! average mass density in the cold pool, in kg m-3
  !$omp THREADPRIVATE(av_rho_m)

  real theta_v_uns_m
  ! virtual potential temperature of the unsaturated downdraft, in K
  !$omp THREADPRIVATE(theta_v_uns_m)

  real C_dw_m ! drag coefficient under cold pools, in m s-1
  !$omp THREADPRIVATE(C_dw_m)

contains

  subroutine set_module_var(eps_cp, beta, av_thvu_constant, k_star, theta_vs, &
       rate_uns, av_rho, theta_v_uns, c_dw)

    real, intent(in):: eps_cp
    ! entrainment coefficient at the border of the cold pool

    real, intent(in):: beta ! entrainment at the top of the mixed layer
    logical, intent(in):: av_thvu_constant
    real, intent(in):: k_star

    real, intent(in):: theta_vs
    ! virtual potential temperature at the surface, in K

    real, intent(in):: rate_uns
    ! mass rate in one unsaturated downdraft, in kg s-1

    real, intent(in):: av_rho ! average mass density in the cold pool, in kg m-3

    real, intent(in):: theta_v_uns
    ! virtual potential temperature of the unsaturated downdraft, in K
    
    real, intent(in):: C_dw ! drag coefficient under cold pools, in m s-1

    !----------------------------------------------

    eps_cp_m = eps_cp
    beta_m = beta
    av_thvu_constant_m = av_thvu_constant
    k_star_m = k_star
    theta_vs_m = theta_vs
    rate_uns_m = rate_uns
    av_rho_m = av_rho
    theta_v_uns_m = theta_v_uns
    c_dw_m = c_dw

  end subroutine set_module_var

end module derivs_param
